@@ -9,7 +9,7 @@
 ## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Light::Connector;
 {
-    $Riak::Light::Connector::VERSION = '0.03';
+    $Riak::Light::Connector::VERSION = '0.04';
 }
 ## use critic
 
@@ -17,10 +17,6 @@ use Moo;
 use MooX::Types::MooseLike::Base qw<Num Str Int Bool Object>;
 require bytes;
 
-{
-    bytes::length();
-}
-
 # ABSTRACT: Riak Connector, abstraction to deal with binary messages
 
 has socket => ( is => 'ro', required => 1 );
@@ -105,20 +101,12 @@ Riak::Light::Connector - Riak Connector, abstraction to deal with binary message
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 DESCRIPTION
 
   Internal class
 
-=head1 NAME
-
-  Riak::Light::Connetor - Riak Connector for Riak::Light
-
-=head1 VERSION
-
-  version 0.001
-
 =head1 AUTHOR
 
 Tiago Peczenyj <tiago.peczenyj@gmail.com>
