@@ -9,13 +9,15 @@
 ## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Light::Timeout::TimeOut;
 {
-    $Riak::Light::Timeout::TimeOut::VERSION = '0.03';
+    $Riak::Light::Timeout::TimeOut::VERSION = '0.04';
 }
 ## use critic
 
 use POSIX qw(ETIMEDOUT ECONNRESET);
 use Time::Out qw(timeout);
 use Time::HiRes;
+use Riak::Light::Util qw(is_windows);
+use Carp;
 use Moo;
 use MooX::Types::MooseLike::Base qw<Num Str Int Bool Object>;
 
@@ -28,6 +30,17 @@ has in_timeout  => ( is => 'ro', isa      => Num, default => sub {0.5} );
 has out_timeout => ( is => 'ro', isa      => Num, default => sub {0.5} );
 has is_valid    => ( is => 'rw', isa      => Bool, default => sub {1} );
 
+sub BUILD {
+
+# from Time::Out documentation
+# alarm(2) doesn't interrupt blocking I/O on MSWin32, so 'timeout' won't do that either.
+
+    croak "Time::Out alarm(2) doesn't interrupt blocking I/O on MSWin32!"
+      if is_windows();
+
+    carp "Not Safe: can clobber previous alarm";
+}
+
 sub clean {
     my $self = shift;
     $self->socket->close;
@@ -93,20 +106,12 @@ Riak::Light::Timeout::TimeOut - proxy to read/write using Time::Out as a timeout
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 DESCRIPTION
 
   Internal class
 
-=head1 NAME
-
-  Riak::Light::Timeout::TimeOut -IO Timeout based on Time::Out for Riak::Light
-
-=head1 VERSION
-
-  version 0.001
-
 =head1 AUTHOR
 
 Tiago Peczenyj <tiago.peczenyj@gmail.com>
